#
# spec file for package python-dns-lexicon
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-dns-lexicon
Version:        3.3.3
Release:        bp153.1.21
Summary:        DNS record manipulation utility
License:        MIT
URL:            https://github.com/AnalogJ/lexicon
Source0:        https://github.com/AnalogJ/lexicon/archive/v%{version}.tar.gz#/lexicon-%{version}.tar.gz
BuildRequires:  %{python_module PyNamecheap}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module beautifulsoup4}
BuildRequires:  %{python_module boto3}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module dnspython >= 1.15.0}
BuildRequires:  %{python_module future}
BuildRequires:  %{python_module localzone}
BuildRequires:  %{python_module mock >= 2.0.0}
BuildRequires:  %{python_module pytest >= 3.8.0}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module softlayer}
BuildRequires:  %{python_module tldextract}
BuildRequires:  %{python_module transip >= 0.3.0}
BuildRequires:  %{python_module vcrpy >= 1.13.0}
BuildRequires:  %{python_module xmltodict}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyNamecheap
Requires:       python-PyYAML
Requires:       python-beautifulsoup4
Requires:       python-boto3
Requires:       python-cryptography
Requires:       python-dnspython >= 1.15.0
Requires:       python-future
Requires:       python-localzone
Requires:       python-requests
Requires:       python-setuptools
Requires:       python-softlayer
Requires:       python-tldextract
Requires:       python-transip >= 0.3.0
Requires:       python-vcrpy
Requires:       python-xmltodict
# Completely different pkg but same namespace
Conflicts:      python-lexicon
BuildArch:      noarch
%python_subpackages

%description
Lexicon provides a way to manipulate DNS records on multiple DNS providers
in a standardized way. Lexicon has a CLI, but it can also be used as a
Python library.

Lexicon was designed to be used in automation, specifically letsencrypt.

%prep
%setup -q -n lexicon-%{version}
# remove localzone test as this test requires an internet connection
# will be fixed with next release
rm lexicon/tests/providers/test_localzone.py
# subreg zeep is all time broken so do not test that
rm lexicon/tests/providers/test_subreg.py

# rpmlint
find . -type f -name ".gitignore" -delete

%build
%python_build

# rpmlint
find . -type f -name ".buildinfo" -delete

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest lexicon/tests

%files %{python_files}
%{python_sitelib}
%license LICENSE
%doc README.md
%python3_only %{_bindir}/lexicon

%changelog
* Thu Oct 17 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull in zeep dependency as zeep is borked and on the
  way from TW (subreg plugin no longer available)
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.3.3:
  * Failsafe list of records when some content is missing
  * Update provider specific dependencies link
  * Add DirectAdmin Provider (#418) * Add provider skeleton for DirectAdmin
* Fri Jul 26 2019 pgajdos@suse.com
- version update to 3.3.1
  * Added provider logic & test recordings. Integration tests passed.
  * Added myself to codeowners file
  * Fixed the lint. Removed rtype filter in _update & _delete methods. Added _identifier helper
  * Update integration test recordings. Add provider to readme | iperurena
* Wed May 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.6:
  * Varous pylint fixes
* Fri Apr 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not use pytest macro for now to get this quickly to 15.1
* Fri Apr  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.1:
  * Fix resolution of dependencies in a regular install of lexicon distribution
  * Mark more tests as expected failures
  * Fix the the updates of Gandi records of a specific type (#384)
  * Fix the if-condition that handles the updates of Gandi records of a specific rtype
- Drop merged patch:
  * ioerror.patch
* Fri Mar  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.1.6:
  * Various changes, no upstream changelog
- Add patch to fix network detection:
  * ioerror.patch
- Drop merged patch:
  * multiple-fixes-to-test_hetzner.patch
* Wed Jan 30 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop pytest reqs that are not really needed to reduce dependency
  pull
* Sat Dec 29 2018 Matej Cepl <mcepl@suse.com>
- Remove fix_regexps.patch and replace it with
  multiple-fixes-to-test_hetzner.patch, which fixes the same rpmlint
  issue and fixes test-hetzner above (gh#AnalogJ/lexicon#333)
* Mon Dec 24 2018 mcepl@suse.com
- Requires localzone -> python-localzone
* Wed Dec 19 2018 Matej Cepl <mcepl@suse.com>
- Update to version 3.0.7
- Fix tests (the only excluded tests are test_hetzner because of
  gh#AnalogJ/lexicon#333)
- Add fix_regexps.patch to fix gh#AnalogJ/lexicon#332
* Tue Nov 20 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.0.2
- Update BuildRequries and Requires from setup.py
  and test-requirements.txt
- Re-enable tests/providers/test_namecheap.py as the necessary
  namecheap libraries have been packaged now
- Disable tests/providers/test_localzone.py as this test
  requires an internet connection
* Mon Apr 23 2018 tchvatal@suse.com
- Conflict with python-lexicon that uses same namespace in sitedir
* Mon Apr 16 2018 jengelh@inai.de
- Use POSIX-compliant syntax of find (requires a directory).
  Use -delete in the same go.
- Update descriptions.
* Sun Apr 15 2018 tchvatal@suse.com
- Expand dependencies in order to run tests
* Sat Apr 14 2018 ecsos@opensuse.org
- Update to version 2.2.1
  No changelog from upstream.
* Wed Dec 13 2017 archie.cobbs@gmail.com
- Update to version 2.1.16
* Sun Jul 31 2016 archie.cobbs@gmail.com
- Update to version 1.1.9
  + Add support for setting TTL, with default 60 minutes
  + Add Gandi support
  + Added luadns support
  + Added fdqn method
  + Added certbot plugin
- Add missing requirement for python-setuptools
* Sun Jun 19 2016 archie.cobbs@gmail.com
- Initial creation of package, version 1.1.6
